Crate kcr_cloudwatchlogs_services_k8s_aws

Crate kcr_cloudwatchlogs_services_k8s_aws 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the cloudwatchlogs.services.k8s.aws group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

cloudwatchlogs.services.k8s.aws/v1alpha1

  • LogGroup

Modules

v1alpha1